@@ -10,6 +10,8 @@ import plotly.express as px
 import plotly.graph_objs as go
 from plotly.subplots import make_subplots
 
+import dash_dangerously_set_inner_html
+
 
 class Components:
     chart_bg = '#1f2c56'
@@ -19,7 +21,7 @@ class Components:
                    placeholder="Select Sorting Method",
                    value='Top 20 Net Profit',
                    options=[{'label': 'Top 20 Net Profit', 'value': 'Top 20 Net Profit'},
-                            {'label': 'Top 20 Return/BaH % Difference', 'value': 'Top 20 Return to BaH Ratio'},
+                            {'label': 'Top 20 Return-BaH % Difference', 'value': 'Top 20 Return to BaH Ratio'},
                             {'label': 'Top 20 Net Profit/MDD Ratio', 'value': 'Top 20 Net Profit to MDD'}, ],
                    style={'border-radius': '5px',   'font-size': '12px', }),
         style={'padding-left': '15px', 'width': '235px'})
@@ -30,8 +32,12 @@ class Components:
                                                    placeholder="Select Filter",
                                                    options=[
                                                        {'label': 'Exclude Stock', 'value': 'exclude'},
-                                                       {'label': 'Return/BaH % Diff. >', 'value': 'return_to_bah>'},
-                                                       {'label': 'Return/BaH % Diff. <', 'value': 'return_to_bah<'},
+                                                       {'label': 'Return on Capital >', 'value': 'return_on_capital>'},
+                                                       {'label': 'Return on Capital <', 'value': 'return_on_capital<'},
+                                                       {'label': 'Annualized Return >', 'value': 'annualized_return>'},
+                                                       {'label': 'Annualized Return <', 'value': 'annualized_return<'},
+                                                       {'label': 'Return-BaH % Diff. >', 'value': 'return_to_bah>'},
+                                                       {'label': 'Return-BaH % Diff. <', 'value': 'return_to_bah<'},
                                                        {'label': 'Sharp Ratio >', 'value': 'annualized_sr>'},
                                                        {'label': 'Sharp Ratio <', 'value': 'annualized_sr<'},
                                                        {'label': 'MDD Percentage >', 'value': 'mdd_pct>'},
@@ -134,8 +140,6 @@ class Components:
                  dbc.Col(str(period[4]) + ' Days', width=2),
              ]),
 
-            # html.Div(style={'height': '5px', }),
-
             dbc.Row([
                  dbc.Col('pct_change', width=2),
                  dbc.Col(f'{pct_mean[0]}%', width=2),
@@ -145,8 +149,6 @@ class Components:
                  dbc.Col(f'{pct_mean[4]}%', width=2),
              ]),
 
-            # html.Div(style={'height': '5px', }),
-
             dbc.Row([
                  dbc.Col('max_rise', width=2),
                  dbc.Col(f'{rise_mean[0]}%', width=2),
@@ -156,8 +158,6 @@ class Components:
                  dbc.Col(f'{rise_mean[4]}%', width=2),
              ]),
 
-            # html.Div(style={'height': '5px', }),
-
             dbc.Row([
                  dbc.Col('max_fall', width=2),
                  dbc.Col(f'{fall_mean[0]}%', width=2),
@@ -167,7 +167,6 @@ class Components:
                  dbc.Col(f'{fall_mean[4]}%', width=2),
              ]),
 
-            # html.Div(style={'height': '15px', }),
         ])
 
         return div
@@ -254,7 +253,7 @@ class Components:
         per_col_1_1.append(html.Div('Number of Trade'))
         per_col_1_1.append(html.Div('Net Profit'))
         per_col_1_1.append(html.Div('Net Profit/MDD Ratio'))
-        per_col_1_1.append(html.Div('Return/BaH % Diff.'))
+        per_col_1_1.append(html.Div('Return-BaH % Diff.'))
         per_col_1_1.append(html.Div('Win Rate'))
         per_col_1_1.append(html.Div('COV'))
         per_col_1_1.append(html.Div('Total Commission'))
@@ -292,10 +291,6 @@ class Components:
 
         for i in range(len(year_list)):
             try:
-                # print(df[f'{year_list[i]}_win_rate'])
-                # # win_rate = df[f'{year_list[i]}_win_rate']
-                # print(df[f'{year_list[i]}_win_rate'].value())
-                # print(df[f'{year_list[i]}_win_rate'])
                 win_rate = "{:.0%}".format( int(df[f'{year_list[i]}_win_rate'])/100 )
             except:
                 win_rate = '-----'
@@ -326,41 +321,6 @@ class Components:
                                 'font-size': '15px'}),
             ]),
 
-            #
-            # dbc.Row([
-            #     dbc.Col(html.Div('Selected Curve', style={'color': 'Cyan', 'font-size': '15px'}), width=7),
-            #     dbc.Col(html.Div('--', id='save_status',
-            #                      style={'color': 'Grey',
-            #                             'padding-left': '5px',
-            #                             'font-size': '15px'}),
-            #             width=4),
-            #     # dbc.Col(html.Div('--', id='save',
-            #     #                  style={'font-size': '15px',
-            #     #                         'text-align': 'center', 'border-radius': '5px',
-            #     #                         'background-color': 'Grey', 'color':'black',
-            #     #                         }), width=5),
-            #     # dbc.Col(html.Div('List All', id="open",
-            #     #                  style={'font-size': '15px','cursor': 'pointer',
-            #     #                         'text-align': 'center', 'border-radius': '5px',
-            #     #                         'background-color': 'Yellow', 'color':'black',
-            #     #                         }), width=4),
-            # ], style={'padding-right': '20px'}),
-
-            # dbc.Modal(
-            #     [
-            #         # dbc.ModalHeader("HEADER"),
-            #         dbc.ModalBody("List of Saved Strategies here"),
-            #         dbc.ModalBody(html.Div('Close', id="close", style={'font-size': '15px', 'cursor': 'pointer'})),
-            #
-            #         # dbc.ModalFooter(
-            #         #     dbc.Button("CLOSE BUTTON", id="close", className="ml-auto")
-            #         # ),
-            #     ],
-            #     id="modal",
-            # ),
-
-            # html.Div(style={'height': '5px', }),
-
             dbc.Row(html.Div(title), style={'font-size': '11px'}),
 
             html.Div(style={'height': '15px', }),
@@ -401,18 +361,20 @@ class Components:
 
 
     filter_options = {
-            'num_of_trade':'Trade Count',
-            'annualized_sr': 'Sharp Ratio',
-            'mdd_pct':'MDD Percentage',
-            'cov':'COV',
-            'win_rate':'Win Rate',
-            'return_to_bah': 'Return/BnH % Diff.',
-            'exclude': 'Exclude',
+        'num_of_trade':'Trade Count',
+        'return_on_capital': 'Return on Capital',
+        'annualized_return': 'Annualized Return',
+        'annualized_sr': 'Sharp Ratio',
+        'mdd_pct':'MDD Percentage',
+        'cov':'COV',
+        'win_rate':'Win Rate',
+        'return_to_bah': 'Return/BnH % Diff.',
+        'exclude': 'Exclude',
         }
     def update_filter_div(self, filter_list):
         filter_button = []
         for i, element in enumerate(filter_list):
-            # element = filter_list[i]
+            element = filter_list[i]
             filter_full = []
             filter_full.append(html.Div(self. filter_options[element[0]], style={'margin-right': '15px', 'display': 'inline'}))
             filter_full.append(html.Div(element[1], style={'margin-right': '15px', 'display': 'inline'}))
@@ -486,7 +448,7 @@ class Components:
                 hovertemplate = hovertemplate + \
                                 key + " : " + str(graph_df.iloc[i][key]) + "<br>"
             hovertemplate = hovertemplate + "<br>"
-            hovertemplate = hovertemplate + "Return/BaH % Diff. : " + str(
+            hovertemplate = hovertemplate + "Return-BaH % Diff. : " + str(
                 round(graph_df.iloc[i]['return_to_bah'], 2)) + "<br>"
             hovertemplate = hovertemplate + "Net Profit to MDD: " + str(
                 round(graph_df.iloc[i]['net_profit_to_mdd'], 2)) + "<br>"
@@ -782,7 +744,7 @@ class Components:
 
 
     def path_to_dict(self,path):
-        filename = path.split('/')[-1].split('.csv')[0]
+        filename = 'file=' + path.split('file=')[-1].split('.csv')[0]
         parameters = {}
         for element in filename.split('&'):
             key, content = element.split('=')
@@ -836,6 +798,12 @@ class Components:
                 dict['py'] = parameters['file']
                 dict['path'] = equity_path
                 dict['parameters'] = parameters
+                dict['performance'] = {
+                    'initial_capital': "{:,}".format(int(row['initial'])),
+                    'return': "{:.0%}".format(row['return']/100),
+                    'mdd': "{:.0%}".format(row['mdd']/100),
+                    'sharp_ratio': row['sharp'],
+                }
                 equity_curves.append(dict)
 
         line_colour = []
@@ -851,47 +819,68 @@ class Components:
         choices = []
         for i in list(df.index):
             line_height = '120%'
-            text = []
+
+            parameters_text = []
             for key, value in df.iloc[i - 1].parameters.items():
                 if not key == 'file':
-                    text.append(html.Div(f'{key} : {value}',style={'line-height': line_height}))
+                    parameters_text.append(html.Div(f'{key} : {value}',style={'line-height': line_height}))
+
+            performance_text = []
+            for key, value in df.iloc[i - 1].performance.items():
+                performance_text.append(html.Div(f'{key} : {value}',style={'line-height': line_height}))
+
             choices.append({
                 "label": html.Div([
 
                     html.Div('----------------------------------------------------------------------------------'),
 
                     dbc.Row([
-                        dbc.Col([html.Div('Curve', style={'line-height': line_height})],
-                                width=3),
-                        dbc.Col([html.Div(str(i).zfill(3), style={'line-height': line_height})],
-                                width=6),
-                    ]),
+                        dbc.Col([
 
-                    html.Div(style={'height': '5px'}),
+                            dbc.Row([
+                                dbc.Col([html.Div('Curve', style={'line-height': line_height})],
+                                        width=3),
+                                dbc.Col([html.Div(str(i).zfill(3), style={'line-height': line_height})],
+                                        width=6),
+                            ]),
 
-                    dbc.Row([
-                        dbc.Col([html.Div('folder',style={'line-height':line_height})],
-                                width=3),
-                        dbc.Col([html.Div(df.iloc[i - 1].folder,style={'line-height':line_height})],
-                                width=6),
-                    ]),
+                            html.Div(style={'height': '5px'}),
 
-                    html.Div(style={'height': '5px'}),
+                            dbc.Row([
+                                dbc.Col([html.Div('folder',style={'line-height':line_height})],
+                                        width=3),
+                                dbc.Col([html.Div(df.iloc[i - 1].folder,style={'line-height':line_height})],
+                                        width=6),
+                            ]),
 
-                    dbc.Row([
-                        dbc.Col([html.Div('.py',style={'line-height':line_height})],
-                                width=3),
-                        dbc.Col([html.Div(df.iloc[i - 1].py,style={'line-height':line_height})],
-                                width=6),
-                    ]),
+                            html.Div(style={'height': '5px'}),
 
-                    html.Div(style={'height': '5px'}),
+                            dbc.Row([
+                                dbc.Col([html.Div('.py',style={'line-height':line_height})],
+                                        width=3),
+                                dbc.Col([html.Div(df.iloc[i - 1].py,style={'line-height':line_height})],
+                                        width=6),
+                            ]),
+
+                            html.Div(style={'height': '5px'}),
+
+                            dbc.Row([
+                                dbc.Col([html.Div('parameters',style={'line-height':line_height})],
+                                        width=3),
+                                dbc.Col([html.Div(parameters_text,style={'line-height':line_height})],
+                                        width=6),
+                            ]),
+
+                            html.Div(style={'height': '5px'}),
+
+                            dbc.Row([
+                                dbc.Col([html.Div('performance', style={'line-height': line_height})],
+                                        width=3),
+                                dbc.Col([html.Div(performance_text, style={'line-height': line_height})],
+                                        width=6),
+                            ]),
+                        ],width=12),
 
-                    dbc.Row([
-                        dbc.Col([html.Div('parameters',style={'line-height':line_height})],
-                                width=3),
-                        dbc.Col([html.Div(text,style={'line-height':line_height})],
-                                width=6),
                     ]),
 
                 ],style={"display": "inline-block", 'width':'400px'}
@@ -918,6 +907,37 @@ class Components:
             dbc.Row([
                 html.Div(_checklist),
                 html.Div(style={'height': '5px'}),
+                html.Div('----------------------------------------------------------------------------------------------------',
+                         style={'padding-left': '23px'}),
+                html.Div(style={'height': '10px', }),
             ]), style={'padding': '0px', 'font-size': '12px'})
 
-        return df, row
\ No newline at end of file
+        return df, row
+
+
+    def aggregate_performance(self, performance_list):
+        return_on_capital = "{:.1%}".format(performance_list[0])
+        annualized_return = "{:.1%}".format(performance_list[1])
+        annualized_sr = round(performance_list[2],2)
+        mdd_pct = "{:.1%}".format(performance_list[3])
+
+        div = html.Div([
+            dbc.Row([
+                dbc.Col('Return on Capital', width=2),
+                dbc.Col(return_on_capital, width=2),
+            ]),
+            dbc.Row([
+                dbc.Col('Annualized Return', width=2),
+                dbc.Col(annualized_return, width=2),
+            ]),
+            dbc.Row([
+                dbc.Col('Sharp Ratio', width=2),
+                dbc.Col(annualized_sr, width=2),
+            ]),
+            dbc.Row([
+                dbc.Col('MDD Percentage', width=2),
+                dbc.Col(mdd_pct, width=2),
+            ]),
+        ])
+
+        return div
\ No newline at end of file
