@@ -53,7 +53,36 @@ class Plot:
 
         app = Dash(__name__, external_stylesheets=[dbc.themes.SUPERHERO], suppress_callback_exceptions=True)
 
+        my_css_data = """body {
+                  background-color: #1a2245;
+                }
+                        /* width */
+                ::-webkit-scrollbar {
+                  width: 10px !important;
+                  display: block !important;
+                }
+
+                /* Track */
+                ::-webkit-scrollbar-track {
+                  background: #1f2c56 !important;
+                  border-radius: 10px !important;
+                  display: block !important;
+                }
+
+
+                /* Handle */
+                ::-webkit-scrollbar-thumb {
+                  background: #154360;
+                  border-radius: 10px;
+                }
+                """
+        innerHtmlText = "<style>%s</style>" % my_css_data
+
         app.layout = html.Div([
+
+            dash_dangerously_set_inner_html.DangerouslySetInnerHTML(innerHtmlText),
+
+
             html.Div(style={'height': '10px', }),
             html.Div(
                 dbc.Row([
@@ -248,6 +277,7 @@ class Plot:
                         self.chart2_button_clicks = 0
                         self.save_clicks = 0
                         self.chart_type = 1
+                        self.line_selected = -1
                         hist_area = []
                         hist_style = {'display': 'none'}
                         self.init = True
@@ -400,32 +430,14 @@ class Plot:
             return performance_matrix, button_style
 
 
-        # # Model
-        # @app.callback(
-        #     Output("modal", "is_open"),
-        #     [Input("open", "n_clicks"), Input("close", "n_clicks")],
-        #     [State("modal", "is_open")],
-        # )
-        # def toggle_modal(n1, n2, is_open):
-        #     # print('Modal!')
-        #     if n1 or n2:
-        #         return not is_open
-        #     else:
-        #         pass
-        #         # print('No Modal Click')
-        #     return is_open
-
-
         # Save Button
         @app.callback(
             Output('save_status', "children"),
             Output('save_string', "children"),
             Output('save_button', "style"),
-            Input('save_status', "children"),
             Input('save_button', "n_clicks"),
-            State('save_string', "children"),
         )
-        def save_button(save_status, save_clicks, button_string):
+        def save_button(save_clicks):
             if not os.path.isfile('saved_strategies.csv'):
                 pd.DataFrame(columns=['path','initial','return','mdd','sharp']).to_csv('saved_strategies.csv', index=False)
             else:
@@ -436,14 +448,6 @@ class Plot:
             button_string = ''
             button_style = {}
 
-            # Process until first line selected
-            # save_path = self.save_path
-            # if self.init:
-            #     save_status = ''
-            #     button_string = ''
-            #     button_style = {}
-            # print('Trigger!',self.line_selected)
-
             save_path = self.save_path
             if not self.init:
                 if not save_clicks: #
@@ -476,7 +480,7 @@ class Plot:
                                                                               'return': self.return_in_capital,
                                                                               'mdd': self.mdd,
                                                                               'sharp': self.sharp,
-                                                                              },index={10})],
+                                                                              },index=[10])],
                                                      ignore_index=True)
                                 button_available = False
                             else:
